@@ -122,6 +122,12 @@ void KWindowSystemPrivateDummy::setOnDesktop(WId win, int desktop)
     Q_UNUSED(desktop)
 }
 
+void KWindowSystemPrivateDummy::setOnActivities(WId win, const QStringList &activities)
+{
+    Q_UNUSED(win)
+    Q_UNUSED(activities)
+}
+
 #ifndef KWINDOWSYSTEM_NO_DEPRECATED
 WId KWindowSystemPrivateDummy::transientFor(WId window)
 {
@@ -171,16 +177,14 @@ void KWindowSystemPrivateDummy::clearState(WId win, NET::States state)
     Q_UNUSED(state)
 }
 
-void KWindowSystemPrivateDummy::minimizeWindow(WId win, bool animation)
+void KWindowSystemPrivateDummy::minimizeWindow(WId win)
 {
     Q_UNUSED(win)
-    Q_UNUSED(animation)
 }
 
-void KWindowSystemPrivateDummy::unminimizeWindow(WId win, bool animation)
+void KWindowSystemPrivateDummy::unminimizeWindow(WId win)
 {
     Q_UNUSED(win)
-    Q_UNUSED(animation)
 }
 
 void KWindowSystemPrivateDummy::raiseWindow(WId win)
@@ -228,6 +232,11 @@ bool KWindowSystemPrivateDummy::showingDesktop()
     return false;
 }
 
+void KWindowSystemPrivateDummy::setShowingDesktop(bool showing)
+{
+    Q_UNUSED(showing);
+}
+
 void KWindowSystemPrivateDummy::setUserTime(WId win, long time)
 {
     Q_UNUSED(win)
@@ -391,6 +400,12 @@ void KWindowSystem::setOnDesktop(WId win, int desktop)
     d->setOnDesktop(win, desktop);
 }
 
+void KWindowSystem::setOnActivities(WId win, const QStringList &activities)
+{
+    Q_D(KWindowSystem);
+    d->setOnActivities(win, activities);
+}
+
 WId KWindowSystem::activeWindow()
 {
     Q_D(KWindowSystem);
@@ -456,6 +471,19 @@ QPixmap KWindowSystem::icon(WId win, int width, int height, bool scale, int flag
     return d->icon(win, width, height, scale, flags);
 }
 
+QPixmap KWindowSystem::icon(WId win, int width, int height, bool scale, int flags, NETWinInfo *info)
+{
+    Q_D(KWindowSystem);
+#if KWINDOWSYSTEM_HAVE_X11
+    if (KWindowSystemPrivateX11 *xd = dynamic_cast<KWindowSystemPrivateX11*>(d)) {
+        return xd->icon(width, height, scale, flags, info);
+    }
+#else
+    Q_UNUSED(info)
+#endif
+    return d->icon(win, width, height, scale, flags);
+}
+
 void KWindowSystem::setIcons(WId win, const QPixmap &icon, const QPixmap &miniIcon)
 {
     Q_D(KWindowSystem);
@@ -480,18 +508,34 @@ void KWindowSystem::clearState(WId win, NET::States state)
     d->clearState(win, state);
 }
 
-void KWindowSystem::minimizeWindow(WId win, bool animation)
+void KWindowSystem::minimizeWindow(WId win)
 {
     Q_D(KWindowSystem);
-    d->minimizeWindow(win, animation);
+    d->minimizeWindow(win);
 }
 
-void KWindowSystem::unminimizeWindow(WId win, bool animation)
+void KWindowSystem::unminimizeWindow(WId win)
 {
     Q_D(KWindowSystem);
-    d->unminimizeWindow(win, animation);
+    d->unminimizeWindow(win);
 }
 
+#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+void KWindowSystem::minimizeWindow(WId win, bool animation)
+{
+    Q_UNUSED(animation)
+    minimizeWindow(win);
+}
+#endif
+
+#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+void KWindowSystem::unminimizeWindow(WId win, bool animation)
+{
+    Q_UNUSED(animation)
+    unminimizeWindow(win);
+}
+#endif
+
 void KWindowSystem::raiseWindow(WId win)
 {
     Q_D(KWindowSystem);
@@ -540,6 +584,12 @@ bool KWindowSystem::showingDesktop()
     return d->showingDesktop();
 }
 
+void KWindowSystem::setShowingDesktop(bool showing)
+{
+    Q_D(KWindowSystem);
+    return d->setShowingDesktop(showing);
+}
+
 void KWindowSystem::setUserTime(WId win, long time)
 {
     Q_D(KWindowSystem);
